@@ -8,6 +8,7 @@ from mkdocs.config import config_options
 from mkdocs.structure.files import File
 from mkdocs.structure.pages import Page
 from mkdocs.utils import write_file, copy_file, get_relative_url, warning_filter
+from mkdocs.exceptions import PluginError
 
 from mkdocs_print_site_plugin.renderer import Renderer
 from mkdocs_print_site_plugin.utils import flatten_nav, get_theme_name
@@ -37,6 +38,7 @@ class PrintSitePlugin(BasePlugin):
         ("add_print_site_banner", config_options.Type(bool, default=False)),
         ("print_site_banner_template", config_options.Type(str, default="")),
         ("path_to_pdf", config_options.Type(str, default="")),
+        ("include_css", config_options.Type(bool, default=True)),
         ("enabled", config_options.Type(bool, default=True)),
         ("exclude", config_options.Type(list, default=[])),
     )
@@ -65,7 +67,9 @@ class PrintSitePlugin(BasePlugin):
             logger.warning(msg)
 
         if "--dirtyreload" in sys.argv:
-            msg = "[mkdocs-print-site] Note the 'print-site' page does render all pages "
+            msg = (
+                "[mkdocs-print-site] Note the 'print-site' page does render all pages "
+            )
             msg += "when using the --dirtyreload option."
             logger.warning(msg)
 
@@ -73,7 +77,9 @@ class PrintSitePlugin(BasePlugin):
         self.cover_page_template_path = ""
         if self.config.get("add_cover_page"):
             if self.config.get("cover_page_template") == "":
-                self.cover_page_template_path = os.path.join(HERE, "templates", "cover_page.tpl")
+                self.cover_page_template_path = os.path.join(
+                    HERE, "templates", "cover_page.tpl"
+                )
             else:
                 self.cover_page_template_path = os.path.join(
                     os.path.dirname(config.get("config_file_path")),
@@ -83,13 +89,17 @@ class PrintSitePlugin(BasePlugin):
                 msg = "[print-site-plugin]: Path specified in 'cover_page_template' not found."
                 msg += "\nMake sure to use the URL relative to your mkdocs.yml file."
                 logger.warning(msg)
-                raise FileNotFoundError("File not found: %s" % self.cover_page_template_path)
+                raise FileNotFoundError(
+                    "File not found: %s" % self.cover_page_template_path
+                )
 
         # Get abs path to print_site_banner_template
         self.banner_template_path = ""
         if self.config.get("add_print_site_banner"):
             if self.config.get("print_site_banner_template") == "":
-                self.banner_template_path = os.path.join(HERE, "templates", "print_site_banner.tpl")
+                self.banner_template_path = os.path.join(
+                    HERE, "templates", "print_site_banner.tpl"
+                )
             else:
                 self.banner_template_path = os.path.join(
                     os.path.dirname(config.get("config_file_path")),
@@ -99,22 +109,25 @@ class PrintSitePlugin(BasePlugin):
                 msg = "[print-site-plugin]: Path specified in 'print_site_banner_template' not found."
                 msg += "\nMake sure to use the URL relative to your mkdocs.yml file."
                 logger.warning(msg)
-                raise FileNotFoundError("File not found: %s" % self.banner_template_path)
+                raise FileNotFoundError(
+                    "File not found: %s" % self.banner_template_path
+                )
 
         # Add pointer to print-site javascript
         config["extra_javascript"] = ["js/print-site.js"] + config["extra_javascript"]
 
         # Add pointer to theme specific css files
-        file = "print-site-%s.css" % get_theme_name(config)
-        if file in os.listdir(os.path.join(HERE, "css")):
-            config["extra_css"] = ["css/%s" % file] + config["extra_css"]
-        else:
-            msg = f"[mkdocs-print-site] Theme '{get_theme_name(config)}' not yet supported\n"
-            msg += "which means print margins and page breaks might be off. Feel free to open an issue!"
-            logger.warning(msg)
+        if self.config.get("include_css"):
+            file = "print-site-%s.css" % get_theme_name(config)
+            if file in os.listdir(os.path.join(HERE, "css")):
+                config["extra_css"] = ["css/%s" % file] + config["extra_css"]
+            else:
+                msg = f"[mkdocs-print-site] Theme '{get_theme_name(config)}' not yet supported\n"
+                msg += "which means print margins and page breaks might be off. Feel free to open an issue!"
+                logger.warning(msg)
 
-        # Add pointer to print-site css files
-        config["extra_css"] = ["css/print-site.css"] + config["extra_css"]
+            # Add pointer to print-site css files
+            config["extra_css"] = ["css/print-site.css"] + config["extra_css"]
 
         # Create MkDocs Page and File instances
         self.print_file = File(
@@ -139,6 +152,11 @@ class PrintSitePlugin(BasePlugin):
             print_page=self.print_page,
         )
 
+        # Tracker
+        # to see if context has been extracted from
+        # template context
+        self.context = {}
+
         return config
 
     def on_nav(self, nav, config, files, **kwargs):
@@ -178,7 +196,9 @@ class PrintSitePlugin(BasePlugin):
 
         # We need to validate that the first heading on each page is a h1
         # This is required for the print page table of contents and enumeration logic
-        if self.config.get("add_table_of_contents") or self.config.get("enumerate_headings"):
+        if self.config.get("add_table_of_contents") or self.config.get(
+            "enumerate_headings"
+        ):
             if page in self.all_pages_in_nav:
                 match = re.search(r"\<h[0-6]", html)
                 if match:
@@ -189,7 +209,9 @@ class PrintSitePlugin(BasePlugin):
 
         # Link to the PDF version of the entire site on a page.
         if self.config.get("path_to_pdf") != "":
-            page.url_to_pdf = get_relative_url(self.config.get("path_to_pdf"), page.file.url)
+            page.url_to_pdf = get_relative_url(
+                self.config.get("path_to_pdf"), page.file.url
+            )
 
         return html
 
@@ -207,21 +229,30 @@ class PrintSitePlugin(BasePlugin):
         # This can be used to customize a theme and add a print button to each page
         page.url_to_print_page = self.print_file.url_relative_to(page.file)
 
-
     def on_template_context(self, context, template_name, config, **kwargs):
         """
-        The template_context event is called immediately after the context is created 
+        The template_context event is called immediately after the context is created
         for the subject template and can be used to alter the context for that specific template only.
 
         See https://www.mkdocs.org/dev-guide/plugins/#on_template_context
         """
         if not self.config.get("enabled"):
             return
+
         # Save the page context
         # We'll use the same context of the last rendered page
         # And apply it to the print page as well (in on_post_build event)
-        self.context = context
 
+        # Note a theme can have multiple templates
+        # Found a bug where in the mkdocs theme,
+        # the "sitemap.xml" static template
+        # has incorrect 'extra_css' and 'extra_js' paths
+        # leading to breaking the print page
+        # at random (when sitemap.xml was rendered last)
+        # we're assuming here all templates have a 404.html template
+        # print(f"\nName: {template_name}\nContext: {context.get('extra_css')}")
+        if template_name == "404.html":
+            self.context = context
 
     def on_post_build(self, config, **kwargs):
         """
@@ -232,21 +263,32 @@ class PrintSitePlugin(BasePlugin):
         if not self.config.get("enabled"):
             return
 
+        if len(self.context) == 0:
+            msg = "Could not find a template context.\n"
+            msg += "Report an issue at https://github.com/timvink/mkdocs-print-site-plugin\n"
+            msg += f"And mention the template you're using: {get_theme_name(config)}"
+            raise PluginError(msg)
+
         # Add print-site.js
         js_output_base_path = os.path.join(config["site_dir"], "js")
         js_file_path = os.path.join(js_output_base_path, "print-site.js")
         copy_file(os.path.join(os.path.join(HERE, "js"), "print-site.js"), js_file_path)
 
-        # Add print-site.css
-        css_output_base_path = os.path.join(config["site_dir"], "css")
-        css_file_path = os.path.join(css_output_base_path, "print-site.css")
-        copy_file(os.path.join(os.path.join(HERE, "css"), "print-site.css"), css_file_path)
+        if self.config.get("include_css"):
+            # Add print-site.css
+            css_output_base_path = os.path.join(config["site_dir"], "css")
+            css_file_path = os.path.join(css_output_base_path, "print-site.css")
+            copy_file(
+                os.path.join(os.path.join(HERE, "css"), "print-site.css"), css_file_path
+            )
 
-        # Add theme CSS file
-        css_file = "print-site-%s.css" % get_theme_name(config)
-        if css_file in os.listdir(os.path.join(HERE, "css")):
-            css_file_path = os.path.join(css_output_base_path, css_file)
-            copy_file(os.path.join(os.path.join(HERE, "css"), css_file), css_file_path)
+            # Add theme CSS file
+            css_file = "print-site-%s.css" % get_theme_name(config)
+            if css_file in os.listdir(os.path.join(HERE, "css")):
+                css_file_path = os.path.join(css_output_base_path, css_file)
+                copy_file(
+                    os.path.join(os.path.join(HERE, "css"), css_file), css_file_path
+                )
 
         # Combine the HTML of all pages present in the navigation
         self.print_page.content = self.renderer.write_combined()
@@ -260,6 +302,16 @@ class PrintSitePlugin(BasePlugin):
         # Render the theme template for the print page
         html = template.render(self.context)
 
+        # Compatiblity with mkdocs-chart-plugin
+        # As this plugin adds some javascript to every page
+        # It should be included in the print site also
+        if config.get("plugins", {}).get("charts"):
+            html = (
+                config.get("plugins", {})
+                .get("charts")
+                .add_javascript_variables(html, self.print_page, config)
+            )
+
         # Determine calls to required javascript functions
         js_calls = "remove_material_navigation();"
         js_calls += "remove_mkdocs_theme_navigation();"
